@@ -9,16 +9,16 @@
 #ifndef RDPVIEW_H
 #define RDPVIEW_H
 
+#include "rdpsession.h"
 #include "remoteview.h"
 
 #include "rdphostpreferences.h"
 
-// #include <QProcess>
+#include <QCursor>
 #include <QUrl>
 
 #define TCP_PORT_RDP 3389
 
-class RdpSession;
 class QMimeData;
 
 class RdpView : public RemoteView
@@ -30,6 +30,7 @@ public:
                      const QUrl &url = QUrl(),
                      KConfigGroup configGroup = KConfigGroup(),
                      const QString &user = QString(),
+                     const QString &domain = QString(),
                      const QString &password = QString());
 
     ~RdpView() override;
@@ -46,9 +47,12 @@ public:
     HostPreferences *hostPreferences() override;
 
     bool supportsScaling() const override;
+    bool supportsLocalCursor() const override;
+    bool supportsViewOnly() const override;
+
+    void showLocalCursor(LocalCursorState state) override;
     bool scaling() const override;
     void enableScaling(bool scale) override;
-    void setScaleFactor(float factor) override;
 
     QPixmap takeScreenshot() override;
 
@@ -56,6 +60,11 @@ public:
 
 public Q_SLOTS:
     void scaleResize(int w, int h) override;
+    void onAuthRequested();
+    void onVerifyCertificate(RdpSession::CertificateResult *ret, const QString &certificate);
+    void onVerifyChangedCertificate(RdpSession::CertificateResult *ret, const QString &oldCertificate, const QString &newCertificate);
+    void onLogonError(const QString &error);
+    void setRemoteCursor(const QCursor cursor);
 
 protected:
     QSize initialSize();
@@ -72,6 +81,7 @@ private:
 
     QString m_name;
     QString m_user;
+    QString m_domain;
     QString m_password;
     //
     bool m_quitting = false;
@@ -81,6 +91,7 @@ private:
 
     QRect m_pendingRectangle;
     QImage m_pendingData;
+    QCursor m_remoteCursor;
 };
 
 #endif
